@@ -129,7 +129,6 @@ int mod_gm_encrypt(char ** encrypted, char * text, int mode) {
     base64 = gm_malloc(size*2);
     base64[0] = 0;
     base64_encode(crypted, size, base64, size*2);
-    free(*encrypted);
     free(crypted);
     *encrypted = base64;
     return strlen(base64);
@@ -267,7 +266,8 @@ int set_default_options(mod_gm_opt_t *opt) {
     opt->has_latency        = FALSE;
     opt->active             = GM_DISABLED;
 
-    opt->workaround_rc_25   = GM_DISABLED;
+    opt->restrict_command_characters = gm_strdup("$&();<>`\"'|");
+    opt->workaround_rc_25            = GM_DISABLED;
 
     opt->host               = NULL;
     opt->service            = NULL;
@@ -382,6 +382,12 @@ int parse_args_line(mod_gm_opt_t *opt, char * arg, int recursion_level) {
     else if (   !strcmp( key, "perfdata" ) ) {
         opt->set_queues_by_hand++;
         opt->perfdata = parse_yes_or_no(value, GM_ENABLED);
+        /* perfdata override to dump all performance values */
+        if(value != NULL) {
+            lc(value);
+            if(!strcmp( value, "all" ))
+                opt->perfdata = GM_PERFDATA_ALL;
+        }
         return(GM_OK);
     }
 
@@ -549,9 +555,12 @@ int parse_args_line(mod_gm_opt_t *opt, char * arg, int recursion_level) {
 
     /* result worker */
     else if ( !strcmp( key, "result_workers" ) ) {
+        gm_log( GM_LOG_ERROR, "result_workers is deprecated and is always set to 1.\n" );
+        /*
         opt->result_workers = atoi( value );
         if(opt->result_workers > GM_LISTSIZE) { opt->result_workers = GM_LISTSIZE; }
         if(opt->result_workers < 0) { opt->result_workers = 0; }
+        */
     }
 
     /* return code */
@@ -882,6 +891,12 @@ int parse_args_line(mod_gm_opt_t *opt, char * arg, int recursion_level) {
         opt->restrict_path_num++;
     }
 
+    /* restrict_command_characters */
+    else if ( !strcmp( key, "restrict_command_characters") ) {
+        free(opt->restrict_command_characters);
+        opt->restrict_command_characters = gm_strdup(value);
+    }
+
     else {
         gm_log( GM_LOG_ERROR, "unknown option '%s'\n", key );
     }
@@ -979,12 +994,14 @@ void dumpconfig(mod_gm_opt_t *opt, int mode) {
         gm_log( GM_LOG_DEBUG, "p1_file:                         %s\n", opt->p1_file == NULL ? "not set" : opt->p1_file );
         for(i=0;i<opt->restrict_path_num;i++)
             gm_log( GM_LOG_DEBUG, "restricted path:                 %s\n", opt->restrict_path[i]);
+        if(opt->restrict_path_num > 0)
+            gm_log( GM_LOG_DEBUG, "restrict_command_characters:     %s\n", opt->restrict_command_characters);
 #endif
     }
     if(mode == GM_NEB_MODE) {
         gm_log( GM_LOG_DEBUG, "queue by cust var:               %s\n", opt->queue_cust_var == NULL ? "no" : opt->queue_cust_var);
         gm_log( GM_LOG_DEBUG, "debug result:                    %s\n", opt->debug_result == GM_ENABLED ? "yes" : "no");
-        gm_log( GM_LOG_DEBUG, "result_worker:                   %d\n", opt->result_workers);
+        //gm_log( GM_LOG_DEBUG, "result_worker:                   %d\n", opt->result_workers);
         gm_log( GM_LOG_DEBUG, "do_hostchecks:                   %s\n", opt->do_hostchecks == GM_ENABLED ? "yes" : "no");
         gm_log( GM_LOG_DEBUG, "route_eventhandler_like_checks:  %s\n", opt->route_eventhandler_like_checks == GM_ENABLED ? "yes" : "no");
     }
@@ -1080,6 +1097,7 @@ void mod_gm_free_opt(mod_gm_opt_t *opt) {
     for(i=0;i<opt->restrict_path_num;i++) {
         free(opt->restrict_path[i]);
     }
+    free(opt->restrict_command_characters);
     free(opt->crypt_key);
     free(opt->keyfile);
     free(opt->message);
