@@ -55,7 +55,7 @@
 #define MOD_GM_COMMON_H
 
 /* constants */
-#define GM_VERSION                 "2.1.2"
+#define GM_VERSION                 "2.1.4"
 #define GM_ENABLED                      1
 #define GM_DISABLED                     0
 #define GM_BUFFERSIZE               65536
@@ -70,6 +70,8 @@
 #define GM_ERROR                        1
 #define GM_NO_EPN                      -1
 
+#define GM_PERFDATA_ALL                 2
+
 #define GM_EXIT_UNKNOWN               768   /* results in exit code 3 after processed by WEXITSTATUS() */
 
 /* log modes */
@@ -241,6 +243,7 @@ typedef struct mod_gm_opt_struct {
 #endif
     char         * restrict_path[GM_LISTSIZE];              /**< list of path restrictions */
     int            restrict_path_num;                       /**< number of path restrictions */
+    char         * restrict_command_characters;             /**< forbidden characters in command lines */
     int            workaround_rc_25;                        /**< optional workaround for plugins returning exit code 25 */
 /* send_gearman */
     int            timeout;                                 /**< timeout for waiting reading on stdin */
